@@ -3,7 +3,7 @@
 # Copyright 2012 Vincent Jacques
 # vincent@vincent-jacques.net
 
-# This file is part of PyGithub. http://vincent-jacques.net/PyGithub
+# This file is part of PyGithub. http://jacquev6.github.com/PyGithub/
 
 # PyGithub is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License
 # as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
@@ -20,33 +20,55 @@ import github.GitObject
 
 
 class GitTag(github.GithubObject.GithubObject):
+    """
+    This class represents GitTags as returned for example by http://developer.github.com/v3/todo
+    """
+
     @property
     def message(self):
+        """
+        :type: string
+        """
         self._completeIfNotSet(self._message)
         return self._NoneIfNotSet(self._message)
 
     @property
     def object(self):
+        """
+        :type: :class:`github.GitObject.GitObject`
+        """
         self._completeIfNotSet(self._object)
         return self._NoneIfNotSet(self._object)
 
     @property
     def sha(self):
+        """
+        :type: string
+        """
         self._completeIfNotSet(self._sha)
         return self._NoneIfNotSet(self._sha)
 
     @property
     def tag(self):
+        """
+        :type: string
+        """
         self._completeIfNotSet(self._tag)
         return self._NoneIfNotSet(self._tag)
 
     @property
     def tagger(self):
+        """
+        :type: :class:`github.GitAuthor.GitAuthor`
+        """
         self._completeIfNotSet(self._tagger)
         return self._NoneIfNotSet(self._tagger)
 
     @property
     def url(self):
+        """
+        :type: string
+        """
         self._completeIfNotSet(self._url)
         return self._NoneIfNotSet(self._url)
 
