@@ -3,7 +3,7 @@
 # Copyright 2012 Vincent Jacques
 # vincent@vincent-jacques.net
 
-# This file is part of PyGithub. http://vincent-jacques.net/PyGithub
+# This file is part of PyGithub. http://jacquev6.github.com/PyGithub/
 
 # PyGithub is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License
 # as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
@@ -19,12 +19,13 @@ import GithubException
 
 
 class _NotSetType:
-    pass
+    def __repr__(self):
+        return "NotSet"  # pragma no cover
 NotSet = _NotSetType()
 
 
 class BasicGithubObject(object):
-    def __init__(self, requester, attributes, completed):  # 'completed' may be removed if I find a way
+    def __init__(self, requester, attributes, completed):
         self._requester = requester
         self._initAttributes()
         self._useAttributes(attributes)
