@@ -3,7 +3,7 @@
 # Copyright 2012 Vincent Jacques
 # vincent@vincent-jacques.net
 
-# This file is part of PyGithub. http://vincent-jacques.net/PyGithub
+# This file is part of PyGithub. http://jacquev6.github.com/PyGithub/
 
 # PyGithub is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License
 # as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
@@ -17,16 +17,29 @@ import github.GithubObject
 
 
 class IssuePullRequest(github.GithubObject.BasicGithubObject):
+    """
+    This class represents IssuePullRequests as returned for example by http://developer.github.com/v3/todo
+    """
+
     @property
     def diff_url(self):
+        """
+        :type: string
+        """
         return self._NoneIfNotSet(self._diff_url)
 
     @property
     def html_url(self):
+        """
+        :type: string
+        """
         return self._NoneIfNotSet(self._html_url)
 
     @property
     def patch_url(self):
+        """
+        :type: string
+        """
         return self._NoneIfNotSet(self._patch_url)
 
     def _initAttributes(self):
