@@ -3,7 +3,7 @@
 # Copyright 2012 Vincent Jacques
 # vincent@vincent-jacques.net
 
-# This file is part of PyGithub. http://vincent-jacques.net/PyGithub
+# This file is part of PyGithub. http://jacquev6.github.com/PyGithub/
 
 # PyGithub is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License
 # as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
@@ -17,20 +17,36 @@ import github.GithubObject
 
 
 class Plan(github.GithubObject.BasicGithubObject):
+    """
+    This class represents Plans as returned for example by http://developer.github.com/v3/todo
+    """
+
     @property
     def collaborators(self):
+        """
+        :type: integer
+        """
         return self._NoneIfNotSet(self._collaborators)
 
     @property
     def name(self):
+        """
+        :type: string
+        """
         return self._NoneIfNotSet(self._name)
 
     @property
     def private_repos(self):
+        """
+        :type: integer
+        """
         return self._NoneIfNotSet(self._private_repos)
 
     @property
     def space(self):
+        """
+        :type: integer
+        """
         return self._NoneIfNotSet(self._space)
 
     def _initAttributes(self):
