@@ -3,7 +3,7 @@
 # Copyright 2012 Vincent Jacques
 # vincent@vincent-jacques.net
 
-# This file is part of PyGithub. http://vincent-jacques.net/PyGithub
+# This file is part of PyGithub. http://jacquev6.github.com/PyGithub/
 
 # PyGithub is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License
 # as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
@@ -17,32 +17,55 @@ import github.GithubObject
 
 
 class UserKey(github.GithubObject.GithubObject):
+    """
+    This class represents UserKeys as returned for example by http://developer.github.com/v3/todo
+    """
+
     @property
     def id(self):
+        """
+        :type: integer
+        """
         self._completeIfNotSet(self._id)
         return self._NoneIfNotSet(self._id)
 
     @property
     def key(self):
+        """
+        :type: string
+        """
         self._completeIfNotSet(self._key)
         return self._NoneIfNotSet(self._key)
 
     @property
     def title(self):
+        """
+        :type: string
+        """
         self._completeIfNotSet(self._title)
         return self._NoneIfNotSet(self._title)
 
     @property
     def url(self):
+        """
+        :type: string
+        """
         self._completeIfNotSet(self._url)
         return self._NoneIfNotSet(self._url)
 
     @property
     def verified(self):
+        """
+        :type: bool
+        """
         self._completeIfNotSet(self._verified)
         return self._NoneIfNotSet(self._verified)
 
     def delete(self):
+        """
+        :calls: `DELETE /user/keys/:id <http://developer.github.com/v3/todo>`_
+        :rtype: None
+        """
         headers, data = self._requester.requestJsonAndCheck(
             "DELETE",
             self.url,
@@ -51,6 +74,12 @@ class UserKey(github.GithubObject.GithubObject):
         )
 
     def edit(self, title=github.GithubObject.NotSet, key=github.GithubObject.NotSet):
+        """
+        :calls: `PATCH /user/keys/:id <http://developer.github.com/v3/todo>`_
+        :param title: string
+        :param key: string
+        :rtype: None
+        """
         assert title is github.GithubObject.NotSet or isinstance(title, (str, unicode)), title
         assert key is github.GithubObject.NotSet or isinstance(key, (str, unicode)), key
         post_parameters = dict()
